@@ -6,14 +6,14 @@
 :Example:           ``__version__ = version.get_full_version()``
 :Created By:        Jeff Shurtliff
 :Last Modified:     Jeff Shurtliff
-:Modified Date:     25 Mar 2020
+:Modified Date:     01 May 2020
 """
 
 import warnings
 
 import requests
 
-__version__ = "2.5.0"
+__version__ = "2.5.3"
 
 
 def get_full_version():
